@@ -12,7 +12,6 @@ __js_url__ = None
 from pytube.version import __version__
 from pytube.streams import Stream
 from pytube.captions import Caption
-from pytube.query import CaptionQuery
-from pytube.query import StreamQuery
+from pytube.query import CaptionQuery, StreamQuery
 from pytube.__main__ import YouTube
 from pytube.contrib.playlist import Playlist
