@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 """Library specific exception definitions."""
-from typing import Pattern
-from typing import Union
+from typing import Pattern, Union
 
 
 class PytubeError(Exception):
