@@ -6,25 +6,15 @@ import urllib.parse
 import re
 from collections import OrderedDict
 from datetime import datetime
-from typing import Any
-from typing import Dict
-from typing import List
-from typing import Optional
-from typing import Tuple
-from urllib.parse import parse_qs
-from urllib.parse import parse_qsl
-from urllib.parse import quote
-from urllib.parse import unquote
-from urllib.parse import urlencode
+from typing import Any, Dict, List, Optional, Tuple
+from urllib.parse import parse_qs, parse_qsl, quote, unquote, urlencode
 
 from pytube.cipher import Cipher
-from pytube.exceptions import HTMLParseError
-from pytube.exceptions import LiveStreamError
-from pytube.exceptions import RegexMatchError
+from pytube.exceptions import HTMLParseError, LiveStreamError, RegexMatchError
 from pytube.helpers import regex_search
 from pytube.metadata import YouTubeMetadata
-from pytube.parser import parse_for_object
-from pytube.parser import parse_for_all_objects
+from pytube.parser import parse_for_object, parse_for_all_objects
+
 
 logger = logging.getLogger(__name__)
 
