@@ -7,12 +7,7 @@ import logging
 import os
 import re
 import warnings
-from typing import Any
-from typing import Callable
-from typing import Dict
-from typing import List
-from typing import Optional
-from typing import TypeVar
+from typing import Any, Callable, Dict, List, Optional, TypeVar
 from urllib import request
 
 from pytube.exceptions import RegexMatchError
