@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
-from typing import Any
-from typing import Callable
-from typing import Optional
+from typing import Any, Callable, Optional
 
 
 class Monostate:
