@@ -1,15 +1,10 @@
 # -*- coding: utf-8 -*-
 import os
-from unittest import mock
-from unittest.mock import MagicMock
-from unittest.mock import mock_open
-from unittest.mock import patch
-
 import pytest
+from unittest import mock
+from unittest.mock import MagicMock, mock_open, patch
 
-from pytube import Caption
-from pytube import CaptionQuery
-from pytube import captions
+from pytube import Caption, CaptionQuery, captions
 
 
 def test_float_to_srt_time_format():
