@@ -2,15 +2,11 @@
 import argparse
 import os
 from unittest import mock
-from unittest.mock import MagicMock
-from unittest.mock import patch
+from unittest.mock import MagicMock, patch
 
 import pytest
 
-from pytube import Caption
-from pytube import CaptionQuery
-from pytube import cli
-from pytube import StreamQuery
+from pytube import Caption, CaptionQuery, cli, StreamQuery
 from pytube.exceptions import PytubeError
 
 parse_args = cli._parse_args
