@@ -2,70 +2,65 @@
 import pytest
 from unittest import mock
 
+import pytube.exceptions as exceptions
 from pytube import YouTube
-from pytube.exceptions import LiveStreamError
-from pytube.exceptions import RecordingUnavailable
-from pytube.exceptions import RegexMatchError
-from pytube.exceptions import VideoUnavailable
-from pytube.exceptions import VideoPrivate
-from pytube.exceptions import VideoRegionBlocked
 
 
 def test_video_unavailable():
     try:
-        raise VideoUnavailable(video_id="YLnZklYFe7E")
-    except VideoUnavailable as e:
+        raise exceptions.VideoUnavailable(video_id="YLnZklYFe7E")
+    except exceptions.VideoUnavailable as e:
         assert e.video_id == "YLnZklYFe7E"  # noqa: PT017
         assert str(e) == "YLnZklYFe7E is unavailable"
 
 
 def test_regex_match_error():
     try:
-        raise RegexMatchError(caller="hello", pattern="*")
-    except RegexMatchError as e:
+        raise exceptions.RegexMatchError(caller="hello", pattern="*")
+    except exceptions.RegexMatchError as e:
         assert str(e) == "hello: could not find match for *"
 
 
 def test_live_stream_error():
     # Ensure this can be caught as generic VideoUnavailable exception
-    with pytest.raises(VideoUnavailable):
-        raise LiveStreamError(video_id='YLnZklYFe7E')
+    with pytest.raises(exceptions.VideoUnavailable):
+        raise exceptions.LiveStreamError(video_id='YLnZklYFe7E')
     try:
-        raise LiveStreamError(video_id='YLnZklYFe7E')
-    except LiveStreamError as e:
+        raise exceptions.LiveStreamError(video_id='YLnZklYFe7E')
+    except exceptions.LiveStreamError as e:
         assert e.video_id == 'YLnZklYFe7E'  # noqa: PT017
         assert str(e) == 'YLnZklYFe7E is streaming live and cannot be loaded'
 
 
 def test_recording_unavailable_error():
     # Ensure this can be caught as generic VideoUnavailable exception
-    with pytest.raises(VideoUnavailable):
-        raise RecordingUnavailable(video_id='5YceQ8YqYMc')
+    with pytest.raises(exceptions.VideoUnavailable):
+        raise exceptions.RecordingUnavailable(video_id='5YceQ8YqYMc')
     try:
-        raise RecordingUnavailable(video_id='5YceQ8YqYMc')
-    except RecordingUnavailable as e:
+        raise exceptions.RecordingUnavailable(video_id='5YceQ8YqYMc')
+    except exceptions.RecordingUnavailable as e:
         assert e.video_id == '5YceQ8YqYMc'  # noqa: PT017
         assert str(e) == '5YceQ8YqYMc does not have a live stream recording available'
 
 
 def test_private_error():
     # Ensure this can be caught as generic VideoUnavailable exception
-    with pytest.raises(VideoUnavailable):
-        raise VideoPrivate('m8uHb5jIGN8')
+    with pytest.raises(exceptions.VideoUnavailable):
+        raise exceptions.VideoPrivate('m8uHb5jIGN8')
     try:
-        raise VideoPrivate('m8uHb5jIGN8')
-    except VideoPrivate as e:
+        raise exceptions.VideoPrivate('m8uHb5jIGN8')
+    except exceptions.VideoPrivate as e:
         assert e.video_id == 'm8uHb5jIGN8'  # noqa: PT017
         assert str(e) == 'm8uHb5jIGN8 is a private video'
 
 
 def test_region_locked_error():
     # Ensure this can be caught as generic VideoUnavailable exception
-    with pytest.raises(VideoUnavailable):
-        raise VideoRegionBlocked('hZpzr8TbF08')
+    with pytest.raises(exceptions.VideoUnavailable):
+        raise exceptions.VideoRegionBlocked('hZpzr8TbF08')
     try:
-        raise VideoRegionBlocked('hZpzr8TbF08')
-    except VideoRegionBlocked as e:
+        raise exceptions.VideoRegionBlocked('hZpzr8TbF08')
+    except exceptions.VideoRegionBlocked as e:
         assert e.video_id == 'hZpzr8TbF08'  # noqa: PT017
         assert str(e) == 'hZpzr8TbF08 is not available in your region'
 
@@ -78,7 +73,7 @@ def test_raises_video_private(private):
             private['watch_html'].encode('utf-8'),
         ]
         mock_url_open.return_value = mock_url_open_object
-        with pytest.raises(VideoPrivate):
+        with pytest.raises(exceptions.VideoPrivate):
             YouTube('https://youtube.com/watch?v=m8uHb5jIGN8').streams
 
 
@@ -90,7 +85,7 @@ def test_raises_recording_unavailable(missing_recording):
             missing_recording['watch_html'].encode('utf-8'),
         ]
         mock_url_open.return_value = mock_url_open_object
-        with pytest.raises(RecordingUnavailable):
+        with pytest.raises(exceptions.RecordingUnavailable):
             YouTube('https://youtube.com/watch?v=5YceQ8YqYMc').streams
 
 
@@ -102,5 +97,5 @@ def test_raises_video_region_blocked(region_blocked):
             region_blocked['watch_html'].encode('utf-8')
         ]
         mock_url_open.return_value = mock_url_open_object
-        with pytest.raises(VideoRegionBlocked):
+        with pytest.raises(exceptions.VideoRegionBlocked):
             YouTube('https://youtube.com/watch?v=hZpzr8TbF08').streams
